==> ejc-zhengyuan-impl-3.0.0-20241227.024427-13-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanPlatformVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 科研平台
 * 
 * @author generator
 * 
 */
public class KeyanPlatformVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long establishUnitId; // 成立（发起）单位id
    private String establishUnitName; // 成立（发起）单位名称
    private String level; // 级别
    private String platformType; // 平台类型
    private String technologyPlatformName; // 科技平台名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date establishTime; // 成立时间
    private String approvalUnit; // 批准单位
    private String fileNumber; // 文件号
    private String researchField; // 研究领域
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getEstablishUnitId() {
        return establishUnitId;
    }

    @ReferDeserialTransfer
    public void setEstablishUnitId(Long establishUnitId) {
        this.establishUnitId = establishUnitId;
    }
    public String getEstablishUnitName() {
        return establishUnitName;
    }

    public void setEstablishUnitName(String establishUnitName) {
        this.establishUnitName = establishUnitName;
    }
    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }
    public String getPlatformType() {
        return platformType;
    }

    public void setPlatformType(String platformType) {
        this.platformType = platformType;
    }
    public String getTechnologyPlatformName() {
        return technologyPlatformName;
    }

    public void setTechnologyPlatformName(String technologyPlatformName) {
        this.technologyPlatformName = technologyPlatformName;
    }
    public Date getEstablishTime() {
        return establishTime;
    }

    public void setEstablishTime(Date establishTime) {
        this.establishTime = establishTime;
    }
    public String getApprovalUnit() {
        return approvalUnit;
    }

    public void setApprovalUnit(String approvalUnit) {
        this.approvalUnit = approvalUnit;
    }
    public String getFileNumber() {
        return fileNumber;
    }

    public void setFileNumber(String fileNumber) {
        this.fileNumber = fileNumber;
    }
    public String getResearchField() {
        return researchField;
    }

    public void setResearchField(String researchField) {
        this.researchField = researchField;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20251202.033713-51-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanPlatformVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 科研平台
 * 
 * @author generator
 * 
 */
public class KeyanPlatformVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long establishUnitId; // 成立（发起）单位id
    private String establishUnitName; // 成立（发起）单位名称
    private String level; // 级别
    private String platformType; // 平台类型
    private String technologyPlatformName; // 科技平台名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date establishTime; // 成立时间
    private String approvalUnit; // 批准单位
    private String fileNumber; // 文件号
    private String researchField; // 研究领域
    private String remarks; // 备注

    private String errorMsg; // 导入错误信息
    private String runState; // 运行状态1运行2取消

    public String getRunState() {
        return runState;
    }

    public void setRunState(String runState) {
        this.runState = runState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getEstablishUnitId() {
        return establishUnitId;
    }

    @ReferDeserialTransfer
    public void setEstablishUnitId(Long establishUnitId) {
        this.establishUnitId = establishUnitId;
    }
    public String getEstablishUnitName() {
        return establishUnitName;
    }

    public void setEstablishUnitName(String establishUnitName) {
        this.establishUnitName = establishUnitName;
    }
    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }
    public String getPlatformType() {
        return platformType;
    }

    public void setPlatformType(String platformType) {
        this.platformType = platformType;
    }
    public String getTechnologyPlatformName() {
        return technologyPlatformName;
    }

    public void setTechnologyPlatformName(String technologyPlatformName) {
        this.technologyPlatformName = technologyPlatformName;
    }
    public Date getEstablishTime() {
        return establishTime;
    }

    public void setEstablishTime(Date establishTime) {
        this.establishTime = establishTime;
    }
    public String getApprovalUnit() {
        return approvalUnit;
    }

    public void setApprovalUnit(String approvalUnit) {
        this.approvalUnit = approvalUnit;
    }
    public String getFileNumber() {
        return fileNumber;
    }

    public void setFileNumber(String fileNumber) {
        this.fileNumber = fileNumber;
    }
    public String getResearchField() {
        return researchField;
    }

    public void setResearchField(String researchField) {
        this.researchField = researchField;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    
}
